@@ -7,9 +7,6 @@ else
   vendor=Unknown
 fi
 
-export LOCPATH=$(pwd)/locales
-sh $debian_dir/locale-gen
-
 export LANG=C.UTF-8
 
 export DEB_PYTHON_INSTALL_LAYOUT=deb_system
@@ -20,8 +17,8 @@ TESTOPTS="-j 1 -w -uall,-network,-urlfetch,-gui"
 #TESTEXCLUSIONS="$TESTEXCLUSIONS test_dbm"
 
 # test_ensurepip: not yet installed, http://bugs.debian.org/732703
-# ... and then test_venv fails too
-TESTEXCLUSIONS="$TESTEXCLUSIONS test_ensurepip test_venv "
+# ... and then test_venv and test_cppext fail too
+TESTEXCLUSIONS="$TESTEXCLUSIONS test_ensurepip test_venv test_cppext"
 
 # test_lib2to3: see https://bugs.python.org/issue34286
 TESTEXCLUSIONS="$TESTEXCLUSIONS test_lib2to3"
@@ -29,24 +26,17 @@ TESTEXCLUSIONS="$TESTEXCLUSIONS test_lib2to3"
 # test_tcl: see https://bugs.python.org/issue34178
 TESTEXCLUSIONS="$TESTEXCLUSIONS test_tcl"
 
-# FIXME: Failing with OpenSSL 1.2 ...
-# ssl.SSLError: [SSL: CA_MD_TOO_WEAK] ca md too weak (_ssl.c:3401)
+# FIXME: flaky/slow test?
 if [ "$vendor" = Debian ]; then
-  TESTEXCLUSIONS="$TESTEXCLUSIONS test_asyncio test_ftplib test_httplib test_imaplib test_nntplib test_poplib test_ssl"
+  TESTEXCLUSIONS="$TESTEXCLUSIONS test_asyncio"
 fi
 
 # FIXME: testWithTimeoutTriggeredSend: timeout not raised by _sendfile_use_sendfile
 TESTEXCLUSIONS="$TESTEXCLUSIONS test_socket"
 
-# FIXME: issue 34806: some distutils tests fail recently
-TESTEXCLUSIONS="$TESTEXCLUSIONS test_distutils"
-
-# FIXME: test_site tests fail with 3.9
-TESTEXCLUSIONS="$TESTEXCLUSIONS test_site"
-
 # FIXME, failing on the Ubuntu autopkg testers
 if [ "$vendor" = Ubuntu ]; then
-  TESTEXCLUSIONS="$TESTEXCLUSIONS test_code_module test_platform test_site"
+  TESTEXCLUSIONS="$TESTEXCLUSIONS test_code_module"
 fi
 
 # test_ssl currently assumes that OpenSSL is compiled with SECURITY_LEVEL=1
@@ -62,3 +52,21 @@ fi
 
 # FIXME: test_ttk_guionly times out on many buildds
 TESTEXCLUSIONS="$TESTEXCLUSIONS test_ttk_guionly"
+
+# FIXME: test_ttk_textonly started failing in 3.9.1 rc1
+TESTEXCLUSIONS="$TESTEXCLUSIONS test_ttk_textonly"
+
+# FIXME: test_multiprocessing_fork times out sometimes. See #1000188
+TESTEXCLUSIONS="$TESTEXCLUSIONS test_multiprocessing_fork"
+
+# FIXME, tests never run to completion on Ubuntu infra
+if [ "$vendor" = Ubuntu ]; then
+  TESTNEVERCOMPLETE="$TESTNEVERCOMPLETE test_exceptions test_repl"
+fi
+
+# FIXME: Fails with Ubuntu's autopkg test infrastructure
+if [ "$vendor" = Ubuntu ]; then
+  if [ "$(dpkg --print-architecture)" = armhf ]; then
+    TESTEXCLUSIONS="$TESTEXCLUSIONS test_structseq"
+  fi
+fi
